aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorsenyuuri <senyuuri@gmail.com>2020-04-29 11:35:24 +0800
committersenyuuri <senyuuri@gmail.com>2020-04-29 11:35:24 +0800
commit5beeeae81dde9fd1d5cff1a933268ef2bb94d494 (patch)
tree801704a79eec921c703ecf3f19d7873a5fcfae98
parent433c588c4cfc20e181b2e865814a350dd7fd9f06 (diff)
downloadmitmproxy-5beeeae81dde9fd1d5cff1a933268ef2bb94d494.tar.gz
mitmproxy-5beeeae81dde9fd1d5cff1a933268ef2bb94d494.tar.bz2
mitmproxy-5beeeae81dde9fd1d5cff1a933268ef2bb94d494.zip
Improve compatibility of wsgi_flask_app example on OS X
-rw-r--r--examples/simple/wsgi_flask_app.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/simple/wsgi_flask_app.py b/examples/simple/wsgi_flask_app.py
index bbde6913..b34fbc83 100644
--- a/examples/simple/wsgi_flask_app.py
+++ b/examples/simple/wsgi_flask_app.py
@@ -15,9 +15,9 @@ def hello_world() -> str:
addons = [
# Host app at the magic domain "proxapp.local" on port 80. Requests to this
# domain and port combination will now be routed to the WSGI app instance.
- wsgiapp.WSGIApp(app, "proxapp.local", 80)
+ wsgiapp.WSGIApp(app, "example.com", 80)
# SSL works too, but the magic domain needs to be resolvable from the mitmproxy machine due to mitmproxy's design.
# mitmproxy will connect to said domain and use serve its certificate (unless --no-upstream-cert is set)
# but won't send any data.
@@ -15,9 +15,9 @@ def hello_world() -> str:
addons = [
- # Host app at the magic domain "proxapp.local" on port 80. Requests to this
+ # Host app at the magic domain "example.com" on port 80. Requests to this
# domain and port combination will now be routed to the WSGI app instance.